@@ -5,7 +5,9 @@
 # This file is part of the Perspective library, distributed under the terms of
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
+
 from logging import critical
+import os
 
 
 def is_libpsp():
@@ -22,16 +24,18 @@ try:
     from .manager import *  # noqa: F401, F403
     from .tornado_handler import *  # noqa: F401, F403
     from .viewer import *  # noqa: F401, F403
-    from .table.libbinding import make_computations, _set_nthreads
+    from .table.libbinding import (
+        init_expression_parser,
+    )
 
     def set_threadpool_size(nthreads):
         """Sets the size of the global Perspective thread pool, up to the
         total number of available cores, which can be set explicity by
         setting `nthreads` to `None`.
         """
-        _set_nthreads(-1 if nthreads is None else nthreads)
+        os.environ["OMP_THREAD_LIMIT"] = "0" if nthreads is None else str(nthreads)
 
-    make_computations()
+    init_expression_parser()
 except ImportError:
     __is_libpsp__ = False
     critical(
